@@ -1,3 +1,11 @@
+( cd opt/kde/share/doc/HTML/fi/khangman ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/khangman ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
+( cd opt/kde/share/doc/HTML/fi/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/kfind ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf qpl-license.html )
